/**
 * Copyright  Sergey Melnik (Stanford University, Database Group)
 *
 * All Rights Reserved.
 */
package org.w3c.rdf.model;

/**
 * A persistent model
 *
 * @author Sergey Melnik <melnik@db.stanford.edu>
 */

interface PersistentModel extends Model {
  
  /** return true if in-memory model is not in synch with the persistent
   *  store */
  boolean isDirty() throws ModelException;
  
  /**
   * A call to checkpoint indicates that in-memory changes are in a
   * consistent state. The database engine may write through the
   * changes. If <tt>force</tt> is set, the engine must synchronize
   * persistent store with in-memory model. */
  void checkpoint(boolean force) throws ModelException;
  
  /** drops the changes to the model that are not yet in the persistent
   *  store */
  void rollback() throws ModelException;
}
